@@ -36,8 +36,10 @@ const Signals = imports.signals;
 const Application = imports.application;
 const Utils = imports.utils;
 const Path = imports.path;
-const MapLocation = imports.mapLocation;
-const UserLocation = imports.userLocation;
+const MapWalker = imports.mapWalker;
+const SearchResultMarker = imports.searchResultMarker;
+const TurnPointMarker = imports.turnPointMarker;
+const UserLocationMarker = imports.userLocationMarker;
 const _ = imports.gettext.gettext;
 
 const MapType = {
@@ -71,10 +73,11 @@ const MapView = new Lang.Class({
 
     _initView: function() {
         let view = this.get_view();
-        view.set_zoom_level(3);
+        view.zoom_level = 3;
         view.min_zoom_level = MapMinZoom;
         view.goto_animation_mode = Clutter.AnimationMode.EASE_IN_OUT_CUBIC;
-        view.set_reactive(true);
+        view.reactive = true;
+        view.kinetic_mode = true;
 
         view.connect('notify::latitude', this._onViewMoved.bind(this));
         view.connect('notify::longitude', this._onViewMoved.bind(this));
@@ -88,50 +91,45 @@ const MapView = new Lang.Class({
     },
 
     _initLayers: function() {
-        this._routeLayer = new Champlain.PathLayer();
-        this._routeLayer.set_stroke_width(2.0);
+        let strokeColor = new Clutter.Color({ red: 0,
+                                               blue: 255,
+                                               green: 0,
+                                               alpha: 100 });
+        this._routeLayer = new Champlain.PathLayer({ stroke_width: 5.0,
+                                                     stroke_color: strokeColor });
         this.view.add_layer(this._routeLayer);
 
-        this._markerLayer = new Champlain.MarkerLayer();
-        this._markerLayer.set_selection_mode(Champlain.SelectionMode.SINGLE);
-        this.view.add_layer(this._markerLayer);
+        let mode = Champlain.SelectionMode.SINGLE;
+        this._searchResultLayer = new Champlain.MarkerLayer({ selection_mode: mode });
+        this.view.add_layer(this._searchResultLayer);
 
-        this._userLocationLayer = new Champlain.MarkerLayer();
-        this._userLocationLayer.set_selection_mode(Champlain.SelectionMode.SINGLE);
+        this._instructionMarkerLayer = new Champlain.MarkerLayer({ selection_mode: mode });
+        this.view.add_layer(this._instructionMarkerLayer);
+
+        this._userLocationLayer = new Champlain.MarkerLayer({ selection_mode: mode });
         this.view.add_layer(this._userLocationLayer);
     },
 
     _connectRouteSignals: function(route) {
         route.connect('update', this.showRoute.bind(this, route));
-        route.connect('reset', this._routeLayer.remove_all.bind(this._routeLayer));
+        route.connect('reset', (function() {
+            this._routeLayer.remove_all();
+            this._instructionMarkerLayer.remove_all();
+        }).bind(this));
+
     },
 
     setMapType: function(mapType) {
-        if (this.view.map_source.get_id() === mapType)
+        if (this.view.map_source.id === mapType)
             return;
 
         let source = this._factory.create_cached_source(mapType);
-        this.view.set_map_source(source);
-    },
-
-    ensureLocationsVisible: function(locations) {
-        let bbox = new Champlain.BoundingBox({ left:   180,
-                                               right: -180,
-                                               bottom:  90,
-                                               top:    -90 });
-
-        locations.forEach(function(location) {
-            bbox.left   = Math.min(bbox.left,   location.longitude);
-            bbox.right  = Math.max(bbox.right,  location.longitude);
-            bbox.bottom = Math.min(bbox.bottom, location.latitude);
-            bbox.top    = Math.max(bbox.top,    location.latitude);
-        });
-        this.view.ensure_visible(bbox, true);
+        this.view.map_source = source;
     },
 
     gotoUserLocation: function(animate) {
         this.emit('going-to-user-location');
-        this._userLocation.once("gone-to", (function() {
+        Utils.once(this._userLocation, "gone-to", (function() {
             this.emit('gone-to-user-location');
         }).bind(this));
         this._userLocation.goTo(animate);
@@ -156,25 +154,33 @@ const MapView = new Lang.Class({
                                                     Geocode.PlaceType.UNKNOWN,
                                                     location);
 
-        let selected = this._userLocation && this._userLocation.getSelected();
-        this._userLocation = new UserLocation.UserLocation(place, this);
-        this._userLocation.show(this._userLocationLayer);
-        this._userLocation.setSelected(selected);
+        let previousSelected = this._userLocation && this._userLocation.selected;
+        this._userLocation = new UserLocationMarker.UserLocationMarker({ place: place,
+                                                                         mapView: this });
+        this._userLocationLayer.remove_all();
+        this._userLocation.addToLayer(this._userLocationLayer);
+
+        this._userLocation.selected = previousSelected;
+
         this.emit('user-location-changed');
     },
 
-    showLocation: function(place) {
-        this._markerLayer.remove_all();
-        let mapLocation = new MapLocation.MapLocation(place, this);
-
-        mapLocation.show(this._markerLayer);
-
-        return mapLocation;
+    showTurnPoint: function(turnPoint) {
+        let instructionMarker = new TurnPointMarker.InstructionMarker({ turnPoint: turnPoint,
+                                                                        mapView: this });
+        this._instructionMarkerLayer.add_marker(instructionMarker);
+        instructionMarker.goToAndSelect(false);
     },
 
-    showNGotoLocation: function(place) {
-        let mapLocation = this.showLocation(place);
-        mapLocation.goTo(true);
+    showSearchResult: function(place) {
+        this._searchResultLayer.remove_all();
+        let searchResultMarker = new SearchResultMarker.SearchResultMarker({ place: place,
+                                                                             mapView: this });
+
+        this._searchResultLayer.add_marker(searchResultMarker);
+        searchResultMarker.goToAndSelect(true);
+
+        return searchResultMarker;
     },
 
     showRoute: function(route) {
@@ -182,9 +188,6 @@ const MapView = new Lang.Class({
 
         route.path.forEach(this._routeLayer.add_node.bind(this._routeLayer));
 
-        // Animate to the center of the route bounding box
-        // goto() is currently implemented on mapLocation, so we need to go
-        // through some hoops here.
         let [lat, lon] = route.bbox.get_center();
         let place = new Geocode.Place({
             location     : new Geocode.Location({ latitude  : lat,
@@ -194,13 +197,35 @@ const MapView = new Lang.Class({
                                                      left   : route.bbox.left,
                                                      right  : route.bbox.right })
         });
-        let mapLocation = new MapLocation.MapLocation(place, this);
 
-        mapLocation.goTo(true);
+        this._showDestinationTurnpoints();
+        new MapWalker.MapWalker(place, this).goTo(true);
+    },
+
+    _showDestinationTurnpoints: function() {
+        let route = Application.routeService.route;
+        let query = Application.routeService.query;
+        let pointIndex = 0;
+
+        this._instructionMarkerLayer.remove_all();
+        route.turnPoints.forEach(function(turnPoint) {
+            if (turnPoint.isStop()) {
+                let queryPoint = query.filledPoints[pointIndex];
+                let destinationMarker = new TurnPointMarker.DestinationMarker({ turnPoint: turnPoint,
+                                                                                queryPoint: queryPoint,
+                                                                                mapView: this });
+                this._instructionMarkerLayer.add_marker(destinationMarker);
+                pointIndex++;
+            }
+        }, this);
     },
 
     _onViewMoved: function() {
         this.emit('view-moved');
+    },
+
+    onSetMarkerSelected: function(selectedMarker) {
+        this.emit('marker-selected', selectedMarker);
     }
 });
 Utils.addSignalMethods(MapView.prototype);
