@@ -43,9 +43,19 @@ const PlaceEntry = new Lang.Class({
     },
 
     set place(p) {
-        this._place = p;
-        this.text   = p ? p.name : "";
-        this.notify("place");
+        if (p) {
+            if (!this.place ||
+                (this.place.location.latitude != p.location.latitude ||
+                 this.place.location.longitude != p.location.longitude)) {
+                this._place = p;
+                this.text   = p.name;
+                this.notify("place");
+            }
+        } else {
+            this._place = p;
+            this.text   = "";
+            this.notify("place");
+        }
     },
     get place() {
         return this._place;
@@ -61,6 +71,10 @@ const PlaceEntry = new Lang.Class({
         this._mapView = props.mapView;
         delete props.mapView;
 
+        if (!props.loupe)
+            props.primary_icon_name = null;
+        delete props.loupe;
+
         props.completion = this._createCompletion();
         this.parent(props);
 
@@ -84,6 +98,7 @@ const PlaceEntry = new Lang.Class({
 
         completion.connect('match-selected', (function(c, model, iter) {
             this.place = model.get_value(iter, PlaceStore.Columns.PLACE);
+            return true;
         }).bind(this));
 
         return completion;
